I appreciate your desire to contribute to this project

Here's a basic instruction on how to do it:

1. Fork my repository on GitHub

2. Clone your fork locally:

`git clone https://github.com/<your username>/i18nice`

4. `cd` into the folder and install the helper:

`python dev-helper.py install`

4. Make changes to the code.
Don't forget to write tests that will cover your changes, add type hints and adhere to flake8 formatting standard.

5. Commit your changes with proper commit message.
Fix problems identified by the helper if there are any.
You can make several commits.

6. Push the changes and open pull request to my repository

If anything is unclear or you just want to report a bug/request a feature, feel free to open an issue.
